#!/bin/bash
# $Id$

addconfig()
{
	local opts

	if [[ -z ${CONFIG} ]]
	then
		echo "You must define \$CONFIG varibale first!"
		return 1
	fi

	if [[ ! -d $(dirname ${CONFIG}) ]]
	then
		install -d $(dirname ${CONFIG})
	fi

	# check for opts
	case $1 in
		-n) shift; opts=" -n" ;;
		-e) shift; opts=" -e" ;;
	esac

	echo ${opts} "$@" >> ${CONFIG}
}

clearconfig()
{
	if [[ -z ${CONFIG} ]]
	then
		echo "You must define \$CONFIG varibale first!"
		return 1
	fi

	if [[ ! -d $(dirname ${CONFIG}) ]]
	then
		install -d $(dirname ${CONFIG})
	fi
	: > ${CONFIG}
}

is_loc_mounted()
{
	local mountpoint
	local i
	mountpoint=$1

	i="$(cat /proc/mounts | grep " ${mountpoint} " | cut -d ' ' -f2)"
	[[ ${i} != ${mountpoint} ]] && return 1

	return 0
}

trap_exit()
{
	[[ -n ${SWAPHDD} ]] && swapoff ${SWAPHDD}
	is_loc_mounted "${INSTALL_ROOT}/dev" && umount ${INSTALL_ROOT}/dev
	is_loc_mounted "${INSTALL_ROOT}/proc" && umount ${INSTALL_ROOT}/proc
	is_loc_mounted "${INSTALL_ROOT}/sys" && umount ${INSTALL_ROOT}/sys
	is_loc_mounted "${INSTALL_ROOT}/boot" && umount ${INSTALL_ROOT}/boot
	is_loc_mounted "${INSTALL_ROOT}" && umount ${INSTALL_ROOT}
	echo "installation aborted"
	exit 1
}

enter_chroot()
{
	local cmd="$@"

	is_loc_mounted "${INSTALL_ROOT}/proc" || mount -t proc proc ${INSTALL_ROOT}/proc
	is_loc_mounted "${INSTALL_ROOT}/sys" || mount -t sysfs sysfs ${INSTALL_ROOT}/sys
	is_loc_mounted "${INSTALL_ROOT}/dev" || mount -o bind /dev ${INSTALL_ROOT}/dev

	chroot ${INSTALL_ROOT} ${cmd} || die "enter_chroot() '${INSTALL_ROOT}' '${cmd}'"

	is_loc_mounted "${INSTALL_ROOT}/dev" && umount  ${INSTALL_ROOT}/dev
	is_loc_mounted "${INSTALL_ROOT}/sys" && umount ${INSTALL_ROOT}/sys
	is_loc_mounted "${INSTALL_ROOT}/proc" && umount ${INSTALL_ROOT}/proc
}

enter_chroot_installrc()
{
	[ -f ${INSTALL_ROOT}/.installrc ] || die "enter_chroot_installrc() ${INSTALL_ROOT}/.installrc missing"
	enter_chroot /bin/bash -i /.installrc || die "enter_chroot_installrc() run"
	[ -f ${INSTALL_ROOT}/.installrc ] && rm ${INSTALL_ROOT}/.installrc
}
